import React, { useState, useEffect } from 'react'
import Page from "@/components/Page";
import { Col, Row, Card, Button } from 'antd';
import { useTranslation } from 'react-i18next';
import ChangeModalPhone from "./components/ChangeModalPhone";
import ChangeModalPassword from "./components/ChangeModalPassword";
import ChangeModalEmail from "./components/ChangeModalEmail";
import { currentUser } from "@/services/login";
import { useNavigate } from "react-router-dom";

export default (props) => {
  const [visible, setVisible] = useState(false);
  const [opPhone, setOpPhone] = useState(false);
  const [opEmail, setOpEmail] = useState(false);
  const [phone, setPhone] = useState();

  const navigate = useNavigate();

  const { t } = useTranslation();
  useEffect(() => {
    currentUser().then((res) => {
      let secretPhone = (res.user.phone).replace(/(\d{3})\d{4}(\d{4})/, '$1****$2');
      setPhone(secretPhone)
    })
  }, [])

  const onOpenPhone = () => {
    setOpPhone(true);
  }
  const onOpenPassword = () => {
    setVisible(true);
  }
  const onOpenEmail = () => {
    setOpEmail(true);
  }
  return (
    <div style={{ padding: "0 80px" }}>
      <Page>
        <div style={{ display: "flex", alignItems: "stretch" }}>
          <div style={{ flex: 1, marginRight: '24px' }}>
            <Card>
              <div style={{ display: "flex", alignItems: "stretch" }}>
                <div style={{ flex: 0.4, display: "flex", justifyContent: "center" }}>
                  <img src="https://qbitnetwork.com/app/img/password-qbit.957e234a.png" alt={t('accountsettings.title1')} width="100" />
                </div>
                <div style={{ flex: 1.6 }}>
                  <div style={{ display: "flex", justifyContent: "space-between", paddingTop: '10px' }}>
                    <div style={{ fontSize: "16px", fontWeight: "bold" }}>{t('accountsettings.title1')}</div>
                    <Button type="ghost" onClick={onOpenPassword}>{t('accountsettings.btnText1')}</Button>
                  </div>
                  <div style={{ paddingTop: '1em', color: '#bfbfbf' }}>{t('accountsettings.text1')}</div>
                </div>
              </div>
            </Card>
          </div>
          <div style={{ flex: 1 }}>
            <Card>
              <div style={{ display: "flex", alignItems: "stretch" }}>
                <div style={{ flex: 0.4, display: "flex", justifyContent: "center" }}>
                  <img src="https://qbitnetwork.com/app/img/phone-qbit.5eab89b2.png" alt={t('accountsettings.title2')} width="100" />
                </div>
                <div style={{ flex: 1.6 }}>
                  <div style={{ display: "flex", justifyContent: "space-between", paddingTop: '10px' }}>
                    <div style={{ fontSize: "16px", fontWeight: "bold" }}>{t('accountsettings.title2')}</div>
                    <Button type="ghost" onClick={onOpenPhone}>{t('accountsettings.btnText2')}</Button>
                  </div>
                  <div style={{ paddingTop: '1em', color: '#bfbfbf' }}>{t('accountsettings.text2')}{phone}</div>
                </div>
              </div>
            </Card>
          </div>
        </div>

        <div style={{ display: "flex", alignItems: "stretch", marginTop: '24px' }}>
          <div style={{ flex: 0.5, marginRight: '24px' }}>
            <Card>
              <div style={{ display: "flex", alignItems: "stretch" }}>
                <div style={{ flex: 0.4, display: "flex", justifyContent: "center" }}>
                  <img src="./img/email.png" alt={t('accountsettings.title3')} width="100" />
                </div>
                <div style={{ flex: 1.6 }}>
                  <div style={{ display: "flex", justifyContent: "space-between", paddingTop: '10px' }}>
                    <div style={{ fontSize: "16px", fontWeight: "bold" }}>{t('accountsettings.title3')}</div>
                    <Button type="ghost" onClick={onOpenEmail}>{t('accountsettings.btnText3')}</Button>
                  </div>
                  <div style={{ paddingTop: '1em', color: '#bfbfbf' }}>{t('accountsettings.text3')}99****qq.com</div>
                </div>
              </div>
            </Card>
          </div>
        </div>

        <div style={{ margin: '24px 0', fontWeight: '400', fontSize: '24px' }}>{t('accountsettings.sumTitle')}</div>
        <div style={{ display: "flex", alignItems: "stretch", marginTop: '24px' }}>
          <div style={{ flex: 0.5, marginRight: '24px' }}>
            <Card>
              <div style={{ display: "flex", alignItems: "stretch" }}>
                <div style={{ flex: 0.4, display: "flex", justifyContent: "center" }}>
                  <img src="	https://qbitnetwork.com/app/img/business-report-qbit.99ec4666.png" alt={t('accountsettings.title4')} width="100" />
                </div>
                <div style={{ flex: 1.6 }}>
                  <div style={{ display: "flex", justifyContent: "space-between", paddingTop: '10px' }}>
                    <div style={{ fontSize: "16px", fontWeight: "bold" }}>{t('accountsettings.title4')}</div>
                    <Button type="ghost" onClick={() => navigate('/authentication')} >{t('accountsettings.btnText4')}</Button>
                  </div>
                  <div style={{ paddingTop: '1em', color: '#bfbfbf' }}>{t('accountsettings.text4')}</div>
                </div>
              </div>
            </Card>
          </div>
        </div>


        <ChangeModalPhone opPhone={opPhone} setOpPhone={setOpPhone} />
        <ChangeModalPassword visible={visible} setVisible={setVisible} />
        <ChangeModalEmail opEmail={opEmail} setOpEmail={setOpEmail} />
      </Page>
    </div>
  )
}