import React, { useEffect } from "react";
import {
  Divider,
  Card,
  Steps,
  Button,
  Radio,
  Form,
  Input,
  Row,
  Col,
  Select,
  Image,
} from "antd";
import { useTranslation } from "react-i18next";
import useBool from "@/utils/hooks/useBool";
import {
  getTaCompanyRealNameTenantId,
  postTaCompanyRealName,
  putTaCompanyRealName,
} from "@/services/taCompanyRealName";
import { ProForm, ProFormRadio } from "@ant-design/pro-components";

export default (props) => {
  const { index, setIndex } = props;
  const { t } = useTranslation();
  const [form] = Form.useForm();

  const onFinish = (values) => {
    const id = values.realCompanyId;
    if (id) {
      putTaCompanyRealName(id, values).then(() => {
        setIndex(index + 1);
      });
    } else {
      postTaCompanyRealName(values).then((res) => {
        setIndex(index + 1);
      });
    }
  };

  useEffect(() => {
    form.resetFields();
    getTaCompanyRealNameTenantId()
      .then((res) => {
        form.setFieldsValue(res);
      })
      .catch((err) => {});
  }, []);
  const isListedCompany = [
    {
      label: t("authentication.AuthenticationYes"),
      value: "1",
    },
    {
      label: t("authentication.AuthenticationNo"),
      value: "0",
    },
  ];
  return (
    <>
      <div style={{ fontSize: "24px", fontWeight: "400", width: "900px" }}>
        {t("authentication.AuthenticationTitle")}
      </div>
      <Card bordered={false} style={{ width: "900px", paddingLeft: "36px" }}>
        <div style={{ fontSize: "16px", fontWeight: "600" }}>
          {t("authentication.AuthenticationContent1")}
        </div>
        <Form
          form={form}
          size="large"
          layout="vertical"
          onFinish={onFinish}
          style={{ marginTop: "4em" }}
          wrapperCol={{ span: 14 }}
        >
          <Form.Item hidden name="realCompanyId"></Form.Item>
          <Form.Item
            label={t("authentication.AuthenticationLabel1")}
            name="registrationLocation"
          >
            <Select
              placeholder={t("authentication.AuthenticationPlaceholder3")}
            >
              <Select.Option value="中国大陆">中国大陆</Select.Option>
            </Select>
          </Form.Item>
          <Form.Item
            label={t("authentication.AuthenticationLabel2")}
            name="companyNameCn"
          >
            <Input
              placeholder={t("authentication.AuthenticationPlaceholder1")}
            />
          </Form.Item>
          <div
            style={{ fontSize: "11px", color: "#bfbfbf", marginTop: "-20px" }}
          >
            {t("authentication.AuthenticationTip")}
          </div>
          <Form.Item
            label={t("authentication.AuthenticationLabel3")}
            name="companyNameEn"
          >
            <Input
              placeholder={t("authentication.AuthenticationPlaceholder2")}
            />
          </Form.Item>
          <Form.Item
            label={t("authentication.AuthenticationLabel4")}
            name="isListedCompany"
          >
            <Radio.Group options={isListedCompany} />
          </Form.Item>

          <Form.Item style={{ marginTop: "24px" }}>
            <Button type="primary" size="large" htmlType="submit">
              {t("authentication.AuthenticationBtn")}
            </Button>
          </Form.Item>
        </Form>
      </Card>
    </>
  );
};
