import React, { useEffect, useState } from "react";
import {
  Divider,
  Card,
  Steps,
  Button,
  Radio,
  Form,
  Input,
  Row,
  Col,
  Select,
  Image,
} from "antd";
import { useTranslation } from "react-i18next";
import {
  postTaCompanyLegalInfo,
  getTaCompanyLegalInfoTenantId,
  putTaCompanyLegalInfo,
} from "@/services/taCompanyLegalInfo";
import "../style.less";
import { UploadImage } from "@/components/Upload";
import { ProForm } from "@ant-design/pro-components";
import ConpanyDirectorAuthPerson from "./ConpanyDirectorAuthPerson";

export default (props) => {
  const { index, setIndex } = props;
  const { t } = useTranslation();
  const [form] = Form.useForm();

  const onFinish = (values) => {
    const authorizedPersonId = "authorizedPerson-companyLegalId";
    const conpanyDirectorId = "conpanyDirector-companyLegalId";
    // 被授权人
    let authorizedPerson = {},
      //企业董事
      conpanyDirector = {};

    for (const key in values) {
      const prefix = key.split("-")[0];
      const prefix1 = key.split("-")[1];
      if (prefix == "authorizedPerson") {
        authorizedPerson[prefix1] = values[key];
        authorizedPerson["identity"] = "authorizedPerson";
      } else if (prefix == "conpanyDirector") {
        conpanyDirector[prefix1] = values[key];
        conpanyDirector["identity"] = "conpanyDirector";
      }
    }
    const data = [authorizedPerson, conpanyDirector].filter(
      (x) => Object.keys(x).length != 0
    );
    const id = values[authorizedPersonId] || values[conpanyDirectorId];
    if (id) {
      console.log("更新");
      putTaCompanyLegalInfo(id, data).then((res) => {
        setIndex(index + 1);
      });
    } else {
      console.log("新增");
      postTaCompanyLegalInfo(data).then((res) => {
        setIndex(index + 1);
      });
    }

    console.log(data);
  };

  const [showList, setShowList] = useState("conpanyDirector");
  const radioChange = (e) => {
    setShowList(e.target.value);
  };

  const directorRule = {
    identity: [{ require: true, message: "请选择身份" }],
  };

  useEffect(() => {
    form.resetFields();
    getTaCompanyLegalInfoTenantId()
      .then((res) => {
        if (res) {
          const select =
            res.length == 2 ? "authorizedPerson" : "conpanyDirector";
          setShowList(select);
          const data = (res || [])
            .map((x) => {
              const dataObj = {};
              if (x.identity == "authorizedPerson") {
                for (const key in x) {
                  dataObj[`authorizedPerson-${key}`] = x[key];
                }
              } else if (x.identity == "conpanyDirector") {
                for (const key in x) {
                  dataObj[`conpanyDirector-${key}`] = x[key];
                }
              }
              return dataObj;
            })
            .reduce((acc, item) => ({ ...acc, ...item }));

          form.setFieldsValue({
            ...data,
            identity: select,
          });
        }
      })
      .catch((err) => {});
  }, []);

  return (
    <>
      <div style={{ fontSize: "24px", fontWeight: "400" }}>
        {t("authentication.stepsTitle2")}
      </div>
      <Form form={form} layout="vertical" onFinish={onFinish} size="large">
        <Card bordered={false} style={{ width: "900px", marginBottom: "24px" }}>
          {/* 您的身份为 */}
          <div
            style={{
              fontSize: "16px",
              fontWeight: "600",
              marginBottom: "12px",
            }}
          >
            {t("authentication.subTitleRight2")}
          </div>

          <Form.Item
            name="identity"
            rules={directorRule.identity}
            initialValue={showList}
          >
            <Radio.Group onChange={radioChange}>
              <div style={{ marginBottom: "24px" }}>
                <Radio style={{ fontSize: "16px" }} value="conpanyDirector">
                  {t("authentication.directorInfoRadioValue1")}
                </Radio>
                {/* <div style={{ paddingTop: "6px", color: "#bfbfbf" }}>
                  {t("authentication.directorInfoRadioText1")}
                </div> */}
              </div>
              <div style={{ marginBottom: "24px" }}>
                <Radio style={{ fontSize: "16px" }} value="authorizedPerson">
                  {t("authentication.directorInfoRadioValue2")}
                </Radio>
                {/* <div style={{ paddingTop: "6px", color: "#bfbfbf" }}>
                  {t("authentication.directorInfoRadioText2")}
                </div> */}
              </div>
            </Radio.Group>
          </Form.Item>

          <Form.Item noStyle shouldUpdate>
            {({ getFieldValue }) => {
              const identity = getFieldValue("identity");
              return (
                <>
                  {identity == "authorizedPerson" ? (
                    <ConpanyDirectorAuthPerson
                      title={t("authentication.directorInfoRadioValue2")}
                      identity="authorizedPerson"
                    />
                  ) : null}

                  {
                    <ConpanyDirectorAuthPerson
                      title={t("authentication.directorInfoRadioValue1")}
                      identity="conpanyDirector"
                    />
                  }
                </>
              );
            }}
          </Form.Item>
          {/* 被授权人 */}
          {/* {showList == "authorizedPerson" && (
            <ConpanyDirectorAuthPerson
              title={t("authentication.directorInfoRadioValue2")}
              identity="authorizedPerson"
            />
          )}

          <ConpanyDirectorAuthPerson
            title={t("authentication.directorInfoRadioValue1")}
            identity="conpanyDirector"
          /> */}

          <Button
            size="large"
            style={{ width: "6vw", marginRight: "40px" }}
            onClick={() => setIndex(index - 1)}
          >
            上一步
          </Button>
          <Button type="primary" htmlType="submit" style={{ width: "6vw" }}>
            {t("authentication.foundationInfoNextBtn")}
          </Button>
        </Card>
      </Form>
    </>
  );
};
