import React, { useEffect, useState } from "react";
import { Card, Button, Radio, Form, Select } from "antd";
import UploadFile from "@/components/Upload/UploadFile";
import { useTranslation } from "react-i18next";
import {
  getTaCompanyBeneficiaryInfoTenantId,
  postTaCompanyBeneficiaryInfo,
  putTaCompanyBeneficiaryInfo,
} from "@/services/taCompanyBeneficiaryInfo";
import "../style.less";
import { getTaCompanyLegalInfoTenantId } from "@/services/taCompanyLegalInfo";
import RadioTitle from "./RadioTitle";
import { ProForm } from "@ant-design/pro-components";
import ConpanyDirectorAuthPersonBeneficiary from "./ConpanyDirectorAuthPersonBeneficiary";

export default (props) => {
  const { index, setIndex } = props;
  const { t } = useTranslation();
  const [form] = Form.useForm();

  // const [ratio, setRatio] = useState("0");
  const onFinish = (values) => {
    console.log("----------->", values);
    const authorizedPersonId = "authorizedPerson-beneficiaryId";

    const conpanyDirectorId = "conpanyDirector-beneficiaryId";

    const id = values[authorizedPersonId] || values[conpanyDirectorId];

    // 被授权人
    let authorizedPerson = {},
      //企业董事
      conpanyDirector = {};
    // 其他受益人
    const otherBeneficiary = [];

    for (const key in values) {
      const prefix = key.split("-")[0];
      const prefix1 = key.split("-")[1];
      if (prefix == "authorizedPerson") {
        authorizedPerson[prefix1] = values[key];
        authorizedPerson["identity"] = "authorizedPerson";
      } else if (prefix == "conpanyDirector") {
        conpanyDirector[prefix1] = values[key];
        conpanyDirector["identity"] = "conpanyDirector";
      } else if (parseInt(prefix) == prefix) {
        if (!otherBeneficiary[prefix - 1]) {
          otherBeneficiary[prefix - 1] = {};
        }
        otherBeneficiary[parseInt(prefix) - 1][prefix1] = values[key];
      }
    }
    let beneficiaryInfoList = [];
    if ((authorizedPerson = {})) {
      beneficiaryInfoList = [conpanyDirector];
    } else if ((conpanyDirector = {})) {
      beneficiaryInfoList = [authorizedPerson];
    } else {
      beneficiaryInfoList = [authorizedPerson, conpanyDirector];
    }

    const data = {
      beneficiaryInfoList: beneficiaryInfoList,
      beneficiaryItemList: otherBeneficiary,
    };

    putTaCompanyBeneficiaryInfo(id, data).then(
      (res) => {
        setIndex(index + 1);
      }
    );
  };
  const onBack = () => {
    setIndex(index - 1);
  };
  // const onChange = (e) => {
  //   setRatio(e.target.value);
  // };
  const [otherBeneficiaryNum, setOtherBeneficiaryNum] = useState(1);

  useEffect(() => {
    form.resetFields();
    getTaCompanyBeneficiaryInfoTenantId()
      .then((res) => {
        if (res) {
          const BeneficiaryNum = res[1]?.length || 0;

          setOtherBeneficiaryNum(BeneficiaryNum || 1);
          const isOtherBeneficiary = BeneficiaryNum > 0 ? "1" : "0";

          const data = (res[0] || [])
            .map((x) => {
              const dataObj = {};
              if (x.identity == "authorizedPerson") {
                for (const key in x) {
                  dataObj[`authorizedPerson-${key}`] = x[key];
                }
              } else if (x.identity == "conpanyDirector") {
                for (const key in x) {
                  dataObj[`conpanyDirector-${key}`] = x[key];
                }
              }
              return dataObj;
            })
            .reduce((acc, item) => ({ ...acc, ...item }));

          const data1 = [];
          res[1].map((x, index) => {
            //
            for (const key in x) {
              data1[`${index + 1}-${key}`] = x[key];
            }
          });
          console.log(data1);
          // console.log(data);
          form.setFieldsValue({
            ...data,
            otherBeneficiaryNum: BeneficiaryNum || 1,
            isOtherBeneficiary: isOtherBeneficiary,
            ...data1,
          });
        }
      })
      .catch((err) => {});
  }, []);

  return (
    <>
      <div style={{ fontSize: "24px", fontWeight: "400" }}>
        {t("authentication.everyoneInfoTitle")}
      </div>
      <Card bordered={false} style={{ width: "900px", marginBottom: "24px" }}>
        <div style={{ fontSize: "16px", marginBottom: "24px" }}>
          {t("authentication.everyoneInfoContent1")}
        </div>
        <div style={{ fontSize: "16px", fontWeight: "600" }}>
          {t("authentication.everyoneInfoContent2")}
        </div>
        <ProForm
          form={form}
          layout="vertical"
          onFinish={onFinish}
          size="large"
          style={{ marginTop: "4em" }}
          submitter={false}
        >
          <Form.Item noStyle shouldUpdate>
            {({ getFieldValue }) => {
              const authorizedPerson = getFieldValue(
                "authorizedPerson-beneficiaryName"
              );
              const conpanyDirector = getFieldValue(
                "conpanyDirector-beneficiaryName"
              );
              return (
                <>
                  {authorizedPerson && (
                    <RadioTitle identity="authorizedPerson" />
                  )}
                  {conpanyDirector ? (
                    <RadioTitle identity="conpanyDirector" />
                  ) : null}
                </>
              );
            }}
          </Form.Item>

          {/* {ratio == "1" && (
            <Form.Item
              label={t("authentication.everyoneInfoInputLabel3")}
              name="shareholdingRatio"
              wrapperCol={{ span: 18 }}
            >
              <Input
                placeholder={t("authentication.everyoneInfoPlaceholder")}
                suffix="%"
              />
            </Form.Item>
          )} */}
          {/* <Form.Item
            label={t("authentication.everyoneInfoUploadTitle")}
            name="equityStructureChart"
            style={{ marginTop: "40px", marginBottom: "36px" }}
          >
            <UploadFile />
          </Form.Item> */}

          <Form.Item
            label={t("authentication.everyoneInfoInputLabel2")}
            name="isOtherBeneficiary"
            initialValue="0"
          >
            <Radio.Group>
              <Radio style={{ fontSize: "16px" }} value="1">
                {t("authentication.everyoneInfoInputRadioValue1")}
              </Radio>
              <Radio style={{ fontSize: "16px" }} value="0">
                {t("authentication.everyoneInfoInputRadioValue2")}
              </Radio>
            </Radio.Group>
          </Form.Item>

          <Form.Item noStyle shouldUpdate>
            {({ getFieldValue }) => {
              const isOtherBeneficiary = getFieldValue("isOtherBeneficiary");
              // const arrOtherBeneficiaryNum = [];
              // arrOtherBeneficiaryNum.push();

              return (
                isOtherBeneficiary == 1 && (
                  <>
                    <Form.Item
                      name="otherBeneficiaryNum"
                      label="贵公司其他受益所有人的数量为？"
                      // initialValue={otherBeneficiaryNum || 1}
                    >
                      <Select
                        options={[
                          { value: 1, label: 1 },
                          { value: 2, label: 2 },
                          { value: 3, label: 3 },
                          { value: 4, label: 4 },
                        ]}
                        onChange={setOtherBeneficiaryNum}
                      />
                    </Form.Item>
                    {[...Array(otherBeneficiaryNum)].map((x, index) => {
                      console.log(index);
                      return (
                        <ConpanyDirectorAuthPersonBeneficiary
                          key={index + 1}
                          identity={index + 1}
                          title={`填写第 【${index + 1}】 个受益所有人信息`}
                        />
                      );
                    })}
                  </>
                )
              );
            }}
          </Form.Item>

          <div
            style={{
              marginBottom: "36px",
              color: "#ffac00",
              marginTop: "-24px",
            }}
          >
            {t("authentication.everyoneInfoRadioTip")}
          </div>

          {/* 这个是 我已阅读并同意 的东西，涛哥你看适当放开 */}
          {/* <Form.Item
            name="check"
            rules={[{ required: true, message: "请阅读并勾选协议" }]}
          >
            <Checkbox>
              {t("authentication.everyoneInfoAgreement")}
              <a>{t("authentication.everyoneInfoAgreementTitle1")}</a>
              {t("authentication.everyoneInfoAgreementEnd")}
              <a>{t("authentication.everyoneInfoAgreementTitle2")}</a>
            </Checkbox>
          </Form.Item> */}

          <Form.Item style={{ marginTop: "24px" }}>
            <Button
              size="large"
              style={{ width: "6vw", marginRight: "2vw" }}
              onClick={onBack}
            >
              {t("authentication.everyoneInfoBack")}
            </Button>
            <Button
              size="large"
              type="primary"
              htmlType="submit"
              style={{ width: "6vw" }}
            >
              {t("authentication.everyoneInfoSubmit")}
            </Button>
          </Form.Item>
        </ProForm>
      </Card>
    </>
  );
};
