import React, { useEffect } from "react";
import {
  Divider,
  Card,
  Steps,
  Button,
  Radio,
  Form,
  Input,
  Row,
  Col,
  Select,
} from "antd";
import UploadFile from "@/components/Upload/UploadFile";
import { useTranslation } from "react-i18next";
import {
  getTaCompanyInfo,
  getTaCompanyInfoTenantId,
  postTaCompanyInfo,
  putTaCompanyInfo,
} from "@/services/taCompanyInfo";
import "../style.less";

export default (props) => {
  const { index, setIndex } = props;
  const [form] = Form.useForm();
  const { t } = useTranslation();

  const onFinish = (values) => {
    const id = values.companyId;
    if (id) {
      getTaCompanyInfoTenantId()
        .then((res) => {
          setIndex(index + 1);
        })
        .catch((err) => {});
    } else {
      postTaCompanyInfo(values).then((res) => {
        setIndex(index + 1);
      });
    }
  };

  useEffect(() => {
    form.resetFields();

    getTaCompanyInfoTenantId()
      .then((res) => {
        form.setFieldsValue(res);
      })
      .catch((err) => {});
  }, []);

  const validateMessages = {
    required: "请填写${label}",
    types: {
      certificateIncorporation: "${label} 不是有效的公司注册证书",
      companyBusinessRegistration: "${label} 不是有效的公司商业登记证",
      nnc1Nar1: "${label} 不是有效的NNC1/最新NAR1",
      otherAnnex: "${label} 不是有效的其他证件",
      companyType: "${label} 不是有效的企业类型",
      businessRegistrationNum: "${label} 不是有效的商业登记号",
      registerCountry: "${label} 不是有效的注册-国家",
      registerProvinceRegion: "${label} 不是有效的注册-省/地区",
      registerCity: "${label} 不是有效的注册-市",
      registerSpecificAddress: "${label} 不是有效的注册-具体地址",
      registerPostalCode: "${label} 不是有效的注册-邮政编码",

      realityCountry: "${label} 不是有效的实际经营-国家",
      realityProvinceRegion: "${label} 不是有效的实际经营-省/地区",
      realityCity: "${label} 不是有效的实际经营-市",
      realitySpecificAddress: "${label} 不是有效的实际经营-具体地址",
      realityPostalCode: "${label} 不是有效的实际经营-邮政编码",
      numEmployees: "${label} 不是有效的雇员人数",
      businessPremisesType: "${label} 不是有效的经营场所类型",
    },
  };
  const formRule = {
    certificateIncorporation: [{ required: true }],
    companyBusinessRegistration: [{ required: true }],
    nnc1Nar1: [{ required: true }],
    otherAnnex: [{ required: true }],
    companyType: [{ required: true }],
    businessRegistrationNum: [{ required: true }],
    registerCountry: [{ required: true }],
    registerProvinceRegion: [{ required: true }],
    registerCity: [{ required: true }],
    registerSpecificAddress: [{ required: true }],
    registerPostalCode: [{ required: true }],

    realityCountry: [{ required: true }],
    realityProvinceRegion: [{ required: true }],
    realityCity: [{ required: true }],
    realitySpecificAddress: [{ required: true }],
    realityPostalCode: [{ required: true }],
    numEmployees: [{ required: true }],
    businessPremisesType: [{ required: true }],
  };
  return (
    <>
      <div style={{ fontSize: "24px", fontWeight: "400" }}>
        {t("authentication.titleRight")}
      </div>
      {/* <Card bordered={false} style={{ width: '900px', marginBottom: '24px' }}>
        <div style={{ color: 'red', fontWeight: '600' }}>{t('authentication.rightTopSubTitle')}</div>
        <div style={{ color: '#bfbfbf' }}>{t('authentication.rightTopText')}</div>
      </Card> */}
      <Form
        form={form}
        layout="vertical"
        onFinish={onFinish}
        size="large"
        validateMessages={validateMessages}
      >
        <Form.Item hidden name="companyId"></Form.Item>

        <Card bordered={false} style={{ width: "900px", marginBottom: "24px" }}>
          <div
            style={{
              fontSize: "16px",
              fontWeight: "600",
              marginBottom: "40px",
            }}
          >
            {t("authentication.subTitleRight")}
          </div>
          <Form.Item
            name="certificateIncorporation"
            label={t("authentication.uploadTitle1")}
            rules={formRule.certificateIncorporation}
          >
            <UploadFile />
          </Form.Item>
          <Form.Item
            name="companyBusinessRegistration"
            label={t("authentication.uploadTitle2")}
            rules={formRule.companyBusinessRegistration}
          >
            <UploadFile text1={t("authentication.uploadPromptTextII4")} />
          </Form.Item>
          <Form.Item
            name="nnc1Nar1"
            label={t("authentication.uploadTitle3")}
            rules={formRule.nnc1Nar1}
          >
            <UploadFile
              text2={t("authentication.uploadPromptTextIII4")}
              text3={t("authentication.uploadPromptTextII5")}
            />
          </Form.Item>
          <Form.Item
            name="otherAnnex"
            label={t("authentication.uploadTitle4")}
            rules={formRule.otherAnnex}
          >
            <UploadFile />
          </Form.Item>
        </Card>
        <Card bordered={false} style={{ width: "900px", marginBottom: "24px" }}>
          <Form.Item
            label={t("authentication.formRightLabel1")}
            wrapperCol={{ span: 18 }}
            name="companyType"
            initialValue={1}
            rules={formRule.companyType}
          >
            <Radio.Group>
              <Radio
                style={{
                  fontSize: "16px",
                  fontWeight: "600",
                  paddingBottom: "12px",
                }}
                value="1"
              >
                {t("authentication.enterpriseTypeRadio1")}
              </Radio>
              <Radio
                style={{
                  fontSize: "16px",
                  fontWeight: "600",
                  paddingBottom: "12px",
                }}
                value="2"
              >
                {t("authentication.enterpriseTypeRadio2")}
              </Radio>
              <Radio
                style={{
                  fontSize: "16px",
                  fontWeight: "600",
                  paddingBottom: "12px",
                }}
                value="3"
              >
                {t("authentication.enterpriseTypeRadio3")}
              </Radio>
              <Radio style={{ fontSize: "16px", fontWeight: "600" }} value="4">
                {t("authentication.enterpriseTypeRadio4")}
              </Radio>
            </Radio.Group>
          </Form.Item>
          <Form.Item
            label={t("authentication.formRightLabel2")}
            wrapperCol={{ span: 18 }}
            name="businessRegistrationNum"
            rules={formRule.businessRegistrationNum}
          >
            <Input placeholder={t("authentication.formRightPlaceholder")} />
            {/* <Input.Group>
              <Row>
                <Col span={8}>
                  <Input placeholder="12345678" size="large" />
                </Col>
                <Col span={4}><Input placeholder="000" size="large" /></Col>
              </Row>
            </Input.Group> */}
          </Form.Item>

          <Form.Item
            label={t("authentication.formRightLabel3")}
            wrapperCol={{ span: 18 }}
            name="registerCountry"
            rules={formRule.registerCountry}
          >
            <Select placeholder={t("authentication.formRightPlaceholder2")}>
              <Select.Option value={t("authentication.formRightSelect1")}>
                {t("authentication.formRightSelect1")}
              </Select.Option>
            </Select>
          </Form.Item>

          <Form.Item
            wrapperCol={{ span: 18 }}
            name="registerProvinceRegion"
            rules={formRule.registerProvinceRegion}
          >
            <Select
              placeholder={t("authentication.formRightSelectPlaceholder1")}
            >
              <Select.Option value="北京">北京</Select.Option>
            </Select>
          </Form.Item>
          <Form.Item
            wrapperCol={{ span: 18 }}
            name="registerCity"
            rules={formRule.registerCity}
          >
            <Input
              placeholder={t("authentication.formRightInputPlaceholder2")}
            />
          </Form.Item>
          <Form.Item
            wrapperCol={{ span: 18 }}
            name="registerSpecificAddress"
            rules={formRule.registerSpecificAddress}
          >
            <Input
              placeholder={t("authentication.formRightInputPlaceholder3")}
            />
          </Form.Item>
          <Form.Item
            wrapperCol={{ span: 18 }}
            name="registerPostalCode"
            rules={formRule.registerPostalCode}
          >
            <Input
              placeholder={t("authentication.formRightInputPlaceholder4")}
            />
          </Form.Item>
          {/* 实际经营地址 */}
          <Form.Item
            label={t("authentication.formRightLabel4")}
            wrapperCol={{ span: 18 }}
            name="realityCountry"
            rules={formRule.realityCountry}
          >
            <Select
              placeholder={t("authentication.formRightSelectPlaceholder1")}
            >
              <Select.Option value="中国香港（地区）">
                中国香港（地区）
              </Select.Option>
            </Select>
          </Form.Item>

          <Form.Item
            wrapperCol={{ span: 18 }}
            name="realityProvinceRegion"
            rules={formRule.realityProvinceRegion}
          >
            <Select
              placeholder={t("authentication.formRightSelectPlaceholder1")}
            >
              <Select.Option value="北京">北京</Select.Option>
            </Select>
          </Form.Item>
          <Form.Item
            wrapperCol={{ span: 18 }}
            name="realityCity"
            rules={formRule.realityCity}
          >
            <Input
              placeholder={t("authentication.formRightInputPlaceholder2")}
            />
          </Form.Item>
          <Form.Item
            wrapperCol={{ span: 18 }}
            name="realitySpecificAddress"
            rules={formRule.realitySpecificAddress}
          >
            <Input
              placeholder={t("authentication.formRightInputPlaceholder3")}
            />
          </Form.Item>
          <Form.Item
            wrapperCol={{ span: 18 }}
            name="realityPostalCode"
            rules={formRule.realityPostalCode}
          >
            <Input
              placeholder={t("authentication.formRightInputPlaceholder4")}
            />
          </Form.Item>

          <Form.Item
            label={t("authentication.formRightLabel5")}
            wrapperCol={{ span: 18 }}
            name="numEmployees"
            rules={formRule.numEmployees}
          >
            <Select
              placeholder={t("authentication.formRightInputPlaceholder5")}
            >
              <Select.Option value="1" style={{ backgroundColor: "#FFF" }}>
                {t("authentication.formRightInputNumber1")}
              </Select.Option>
              <Select.Option value="2" style={{ backgroundColor: "#FFF" }}>
                {t("authentication.formRightInputNumber2")}
              </Select.Option>
              <Select.Option value="3" style={{ backgroundColor: "#FFF" }}>
                {t("authentication.formRightInputNumber3")}
              </Select.Option>
            </Select>
          </Form.Item>
          <Form.Item
            label={t("authentication.formRightLabel6")}
            wrapperCol={{ span: 18 }}
            name="businessPremisesType"
            rules={formRule.businessPremisesType}
          >
            <Select
              placeholder={t("authentication.formRightInputPlaceholder6")}
            >
              <Select.Option value="1" style={{ backgroundColor: "#FFF" }}>
                {t("authentication.formRightInputPlace1")}
              </Select.Option>
              <Select.Option value="2" style={{ backgroundColor: "#FFF" }}>
                {t("authentication.formRightInputPlace2")}
              </Select.Option>
              <Select.Option value="3" style={{ backgroundColor: "#FFF" }}>
                {t("authentication.formRightInputPlace3")}
              </Select.Option>
              <Select.Option value="4" style={{ backgroundColor: "#FFF" }}>
                {t("authentication.formRightInputPlace4")}
              </Select.Option>
            </Select>
          </Form.Item>
     
          <Button
            type="primary"
            size="large"
            style={{ width: "6vw" }}
            htmlType="submit"
          >
            {t("authentication.foundationInfoNextBtn")}
          </Button>
        </Card>
      </Form>
    </>
  );
};
